@@ -1,25 +1,29 @@
--- $Id: xor_aggregate.sql 247 2005-03-13 09:31:52Z coelho $
+-- $Id: xor_aggregate.sql 571 2010-03-25 10:18:47Z fabien $
 
 -- default behavior for strict functions used: NULLs are ignored...
 
+DROP AGGREGATE IF EXISTS XOR(bit);
 CREATE AGGREGATE XOR(
   BASETYPE = BIT,
   SFUNC = bitxor,
   STYPE = BIT
 );
 
+DROP AGGREGATE IF EXISTS XOR(INT2);
 CREATE AGGREGATE XOR(
   BASETYPE = INT2,
   SFUNC = int2xor,
   STYPE = INT2
 );
 
+DROP AGGREGATE IF EXISTS XOR(INT4);
 CREATE AGGREGATE XOR(
   BASETYPE = INT4,
   SFUNC = int4xor,
   STYPE = INT4
 );
 
+DROP AGGREGATE IF EXISTS XOR(INT8);
 CREATE AGGREGATE XOR(
   BASETYPE = INT8,
   SFUNC = int8xor,
